import { Attributes as GAttributes } from 'graphology-types';
import { XYPosition } from 'reactflow';
import { MultiGraph } from 'graphology';
import './utils';
import { GeneralDescription, InputNodeType, InputNodeTypeTypes } from '../logic/general';
import { AllLogicTypes } from '../logic';
import { QueryElementTypes } from '../reactflow';

// export interface Attributes extends EntityNode | RelationNode | AttributeNode | FunctionNode | ModifierNode  {
// }

export interface NodeAttribute {
  handleData: QueryGraphEdgeHandle;
  // nodeCount: number;
  // summedNullAmount: number;
  // connectedRatio: number;
  // handles: string[];
}

export type NodeDefaults = {
  id?: string;
  type: QueryElementTypes;
  width?: number;
  height?: number;
  attributes?: NodeAttribute[];
};

/** Interface for the data in an entity node. */
export interface EntityData {
  name?: string;
  leftRelationHandleId?: QueryGraphEdgeHandle;
  rightRelationHandleId?: QueryGraphEdgeHandle;
}

/** Interface for the data in an relation node. */
export interface RelationData {
  name?: string;
  collection: string;
  depth: { min: number; max: number };
  leftEntityHandleId?: QueryGraphEdgeHandle;
  rightEntityHandleId?: QueryGraphEdgeHandle;
}

export interface LogicData {
  name: string;
  // inputType: InputNodeType;
  // logicType: AllLogicTypes;
  // key: string;
  logic: GeneralDescription<AllLogicTypes>;
  inputs: Record<string, InputNodeTypeTypes>; // name from InputNode -> InputNodeTypeTypes
}

export type EntityNodeAttributes = XYPosition & EntityData & NodeDefaults;
export type RelationNodeAttributes = XYPosition & RelationData & NodeDefaults;
export type LogicNodeAttributes = XYPosition & LogicData & NodeDefaults;

export type QueryGraphNodes = EntityNodeAttributes | RelationNodeAttributes | LogicNodeAttributes;

export type QueryGraphEdgeAttribute = {
  attributeName?: string;
  attributeType?: InputNodeType;
};

export type QueryGraphEdgeHandle = {
  nodeId: string;
  nodeName: string;
  nodeType: QueryElementTypes;
} & QueryGraphEdgeAttribute;

export type QueryGraphEdges = {
  type: string;
  sourceHandleData: QueryGraphEdgeHandle;
  targetHandleData: QueryGraphEdgeHandle;
};

export type QueryGraphEdgesOpt = {
  type?: string;
  sourceHandleData?: QueryGraphEdgeHandle;
  targetHandleData?: QueryGraphEdgeHandle;
};

// export class QueryGraph extends Graph<QueryGraphNodes, GAttributes, GAttributes>; // is in utils.ts
