import React, { useEffect } from 'react';
import Draggable from 'react-draggable';
import { AllLogicDescriptions, MathFilters, NumberFunctions, QueryGraphEdgeHandle, StringFilters, StringFunctions } from '../model';
import { InputNodeType } from '../model/logic/general';
import { QuerySidePanel } from './querysidepanel';

export function QueryBuilderModal(props: {
  open: boolean;
  handle: QueryGraphEdgeHandle | undefined;
  onClose: () => void;
  onClick: (item: AllLogicDescriptions) => void;
}) {
  const modal = React.useRef<HTMLDialogElement>(null);

  useEffect(() => {
    if (props.open) {
      modal.current?.showModal();
    } else {
      modal.current?.close();
    }
  }, [props.open]);

  function onClose() {
    props.onClose();
  }

  return (
    <dialog id="my_modal_1" className="modal " ref={modal} onClose={() => onClose()}>
      <form method="dialog" className="modal-box h-auto">
        <QuerySidePanel title="Logic Pills usable by the node" filter={props.handle?.attributeType} onClick={props.onClick} />
      </form>

      <form method="dialog" className="modal-backdrop">
        <button>close</button>
      </form>
    </dialog>
  );
}
