import React from 'react';
import GeoNodeLinkMap from './GeoNodeLinkMap';
import { Provider } from 'react-redux';
import { configureStore } from '@reduxjs/toolkit';
import { graphQueryResultSlice, assignNewGraphQueryResult } from '../../data-access/store';
import { flights } from '../../mock-data/query-result/geo-mock-data';
import { Meta } from '@storybook/react';

const Mockstore = configureStore({
  reducer: {
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

const Component: Meta<typeof GeoNodeLinkMap> = {
  title: 'Components/Visualizations/GeospatialKG',
  component: GeoNodeLinkMap,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const Flights = {
  args: {
    isAggregated: true,
    isFanned: true,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: flights }));
  },
};

export const FlightsAggregated = {
  args: {
    nodelink: 'faceting',
    isAggregated: true,
    isFanned: true,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: flights }));
  },
};

export const FlightsClustered = {
  args: {
    nodelink: 'cluster',
    isAggregated: true,
    isFanned: true,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: flights }));
  },
};

export default Component;
