/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { CompositeLayer } from 'deck.gl/typed';
import { ScatterplotLayer, LineLayer } from '@deck.gl/layers/typed';
import { LayerProps } from '../types';
import { getColor } from '../utils';
import { BrushingExtension } from '@deck.gl/extensions/typed';

export class NodeLinkLayer extends CompositeLayer<LayerProps> {
  /**
   * Basic node-link layer that just visualizes the data
   */
  static componentName = 'Knowledge Graph Layer';

  shouldUpdateState({ changeFlags }: any) {
    return changeFlags.somethingChanged;
  }

  renderLayers() {
    return [
      new LineLayer({
        id: 'edges',
        data: this.props.edges,
        pickable: true,
        extensions: [new BrushingExtension()],
        brushingEnabled: this.props.brushing,
        brushingRadius: 500000,
        brushingTarget: 'source_target',
        getWidth: (d) => d.count,
        getSourcePosition: (d) => d.from_coordinates,
        getTargetPosition: (d) => d.to_coordinates,
        opacity: 0.3,
        getColor: (d) => getColor(d.attributes.prediction, this.props.colorScale),
      }),
      new ScatterplotLayer({
        id: 'nodes',
        data: this.props.nodes,
        pickable: true,
        opacity: 0.5,
        interactive: true,
        filled: true,
        radiusScale: 1,
        radiusMinPixels: 4,
        radiusMaxPixels: 20,
        getPosition: (d) => d.attributes.coordinates,
        getFillColor: [0, 0, 0],
      }),
    ];
  }
}
